[ARVADOS] created: e2ea7599812d12dd027930069ee92e8816ee9de8

Git user git at public.curoverse.com
Tue Feb 21 08:08:02 EST 2017


        at  e2ea7599812d12dd027930069ee92e8816ee9de8 (commit)


commit e2ea7599812d12dd027930069ee92e8816ee9de8
Author: Lucas Di Pentima <lucas at curoverse.com>
Date:   Tue Feb 21 10:00:19 2017 -0300

    11002: When trying to save the cache's state before quitting, if an exception
    is caught because of a BlockManager problem induced by an interruption,
    print a warning message and quit without saving the last checkpoint.

diff --git a/sdk/python/arvados/commands/put.py b/sdk/python/arvados/commands/put.py
index d421d2c..df2ed02 100644
--- a/sdk/python/arvados/commands/put.py
+++ b/sdk/python/arvados/commands/put.py
@@ -452,11 +452,15 @@ class ArvPutUploadJob(object):
                 # Stop the thread before doing anything else
                 self._stop_checkpointer.set()
                 self._checkpointer.join()
-                # Commit all pending blocks & one last _update()
-                self._local_collection.manifest_text()
-                self._update(final=True)
-                if save_collection:
-                    self.save_collection()
+                try:
+                    # Commit all pending blocks & one last _update()
+                    self._local_collection.manifest_text()
+                    self._update(final=True)
+                    if save_collection:
+                        self.save_collection()
+                except AttributeError:
+                    # Exception caught in inconsistent state, finish as is.
+                    self.logger.warning("Couldn't save last checkpoint while exiting.")
             if self.use_cache:
                 self._cache_file.close()
 

commit f69196e8bdc3087bda787b0a2ed3b4c628866a1d
Author: Lucas Di Pentima <lucas at curoverse.com>
Date:   Tue Feb 21 09:54:07 2017 -0300

    11002: Added missing assertion to test.

diff --git a/sdk/python/tests/test_arv_put.py b/sdk/python/tests/test_arv_put.py
index ecb2b80..f9af01d 100644
--- a/sdk/python/tests/test_arv_put.py
+++ b/sdk/python/tests/test_arv_put.py
@@ -347,7 +347,7 @@ class ArvPutUploadJobTest(run_test_server.TestCaseWithServers,
     # Test for bug #11002
     def test_graceful_exit_while_repacking_small_blocks(self):
         def wrapped_commit(*args, **kwargs):
-            raise Exception("Simulated error")
+            raise SystemExit("Simulated error")
 
         with mock.patch('arvados.arvfile._BlockManager.commit_bufferblock',
                         autospec=True) as mocked_commit:
@@ -359,7 +359,8 @@ class ArvPutUploadJobTest(run_test_server.TestCaseWithServers,
             writer = arv_put.ArvPutUploadJob([self.small_files_dir],
                                              replication_desired=1)
             try:
-                writer.start(save_collection=False)
+                with self.assertRaises(SystemExit):
+                    writer.start(save_collection=False)
             except AttributeError:
                 self.fail("arv-put command is trying to use a corrupted BlockManager. See https://dev.arvados.org/issues/11002")
         writer.destroy_cache()

commit 3988d2c68560bf4bc31504ae7f7c4d83a8215b18
Author: Lucas Di Pentima <lucas at curoverse.com>
Date:   Tue Feb 21 08:41:07 2017 -0300

    11002: Improved test mocking a more suitable method and catching the specific exception type.

diff --git a/sdk/python/tests/test_arv_put.py b/sdk/python/tests/test_arv_put.py
index f1dfd03..2067b7c 100644
--- a/sdk/python/tests/test_arv_put.py
+++ b/sdk/python/tests/test_arv_put.py
@@ -261,12 +261,19 @@ class ArvPutUploadJobTest(run_test_server.TestCaseWithServers,
             data = random.choice(['x', 'y', 'z']) * 1024 * 1024 # 1 MB
             fileobj.write(data)
         fileobj.close()
+        # Temp dir containing small files to be repacked
+        self.small_files_dir = tempfile.mkdtemp()
+        data = 'y' * 1024 * 1024 # 1 MB
+        for i in range(1, 70):
+            with open(os.path.join(self.small_files_dir, str(i)), 'w') as f:
+                f.write(data + str(i))
         self.arvfile_write = getattr(arvados.arvfile.ArvadosFileWriter, 'write')
 
     def tearDown(self):
         super(ArvPutUploadJobTest, self).tearDown()
         shutil.rmtree(self.tempdir)
         os.unlink(self.large_file_name)
+        shutil.rmtree(self.small_files_dir)
 
     def test_writer_works_without_cache(self):
         cwriter = arv_put.ArvPutUploadJob(['/dev/null'], resume=False)
@@ -337,6 +344,26 @@ class ArvPutUploadJobTest(run_test_server.TestCaseWithServers,
                          os.path.getsize(self.large_file_name))
         writer2.destroy_cache()
 
+    # Test for bug #11002
+    def test_graceful_exit_while_repacking_small_blocks(self):
+        def wrapped_delete(*args, **kwargs):
+            raise SystemExit("Simulated error")
+
+        with mock.patch('arvados.arvfile._BlockManager._delete_bufferblock',
+                        autospec=True) as mocked_delete:
+            mocked_delete.side_effect = wrapped_delete
+            # Upload a little more than 1 block, wrapped_delete will make the first block
+            # commit to fail.
+            # arv-put should not exit with an exception by trying to commit the collection
+            # as it's in an inconsistent state.
+            writer = arv_put.ArvPutUploadJob([self.small_files_dir],
+                                             replication_desired=1)
+            try:
+                writer.start(save_collection=False)
+            except:
+                self.fail("arv-put command is trying to use a corrupted BlockManager. See https://dev.arvados.org/issues/11002")
+        writer.destroy_cache()
+
     def test_no_resume_when_asked(self):
         def wrapped_write(*args, **kwargs):
             data = args[1]

-----------------------------------------------------------------------


hooks/post-receive
diff --git a/sdk/python/tests/test_arv_put.py b/sdk/python/tests/test_arv_put.py
index 2067b7c..ecb2b80 100644
--- a/sdk/python/tests/test_arv_put.py
+++ b/sdk/python/tests/test_arv_put.py
@@ -346,13 +346,13 @@ class ArvPutUploadJobTest(run_test_server.TestCaseWithServers,
 
     # Test for bug #11002
     def test_graceful_exit_while_repacking_small_blocks(self):
-        def wrapped_delete(*args, **kwargs):
-            raise SystemExit("Simulated error")
+        def wrapped_commit(*args, **kwargs):
+            raise Exception("Simulated error")
 
-        with mock.patch('arvados.arvfile._BlockManager._delete_bufferblock',
-                        autospec=True) as mocked_delete:
-            mocked_delete.side_effect = wrapped_delete
-            # Upload a little more than 1 block, wrapped_delete will make the first block
+        with mock.patch('arvados.arvfile._BlockManager.commit_bufferblock',
+                        autospec=True) as mocked_commit:
+            mocked_commit.side_effect = wrapped_commit
+            # Upload a little more than 1 block, wrapped_commit will make the first block
             # commit to fail.
             # arv-put should not exit with an exception by trying to commit the collection
             # as it's in an inconsistent state.
@@ -360,7 +360,7 @@ class ArvPutUploadJobTest(run_test_server.TestCaseWithServers,
                                              replication_desired=1)
             try:
                 writer.start(save_collection=False)
-            except:
+            except AttributeError:
                 self.fail("arv-put command is trying to use a corrupted BlockManager. See https://dev.arvados.org/issues/11002")
         writer.destroy_cache()
 

commit 142a3c236c911731c337e1f9ee06038e6388e87b
Author: Lucas Di Pentima <lucas at curoverse.com>
Date:   Mon Feb 20 17:25:05 2017 -0300

    11002: Added test to make the bug happen.

-- 




More information about the arvados-commits mailing list